package elections.ui.javafx;

import java.io.FileReader;
import java.io.IOException;
import java.io.Reader;

import elections.persistence.BadFileFormatException;
import elections.persistence.MySeggiWriter;
import elections.persistence.MyVotiReader;
import elections.persistence.SeggiWriter;
import elections.persistence.VotiReader;
import elections.ui.controller.Controller;
import elections.ui.controller.MyController;
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.scene.control.Alert;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.paint.Color;
import javafx.stage.Stage;

public class ElectionApplication extends Application {

	private Controller controller;

	public void start(Stage stage) {
		controller = createController();
		if (controller == null)
			return;
		stage.setTitle("Elezioni a Dentinia");
		ElectionPane root = new ElectionPane(controller);

		Scene scene = new Scene(root, 750, 500, Color.ALICEBLUE);
		stage.setScene(scene);
		stage.show();
	}

	protected Controller createController() {
		try(Reader reader = new FileReader("RisultatiElezioni.txt")) {
			VotiReader votiReader = new MyVotiReader(reader);
			SeggiWriter seggiWriter = new MySeggiWriter("Report.txt");			
			return new MyController(votiReader, seggiWriter);
		} catch (IOException e) {
			alert("Errore di I/O", "Impossibile aprire uno dei file", "Errore nell'apertura del reader o del writer");
			return null;
		} catch (BadFileFormatException e) {
			alert("Errore di I/O", "Errore di formato nel file", "Impossibile effettuare la lettura");
			return null;
		}
	}

	protected void alert(String title, String headerMessage, String contentMessage) {
		Alert alert = new Alert(AlertType.ERROR);
		alert.setTitle(title);
		alert.setHeaderText(headerMessage);
		alert.setContentText(contentMessage);
		alert.showAndWait();
	}

	public static void main(String[] args) {
		launch(args);
	}

}
